==> qgis_3.4.15+dfsg.orig.tar.xz: qgis-3.4.15/python/plugins/processing/algs/grass7/ext/i_albedo.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    i_albedo.py
    -----------
    Date                 : February 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = 'e83d02e2747dd3e4e6940d9d720fee80febe78d9'

from .i import verifyRasterNum


def checkParameterValuesBeforeExecuting(alg, parameters, context):
    if alg.parameterAsBool(parameters, '-m', context):
        return verifyRasterNum(alg, parameters, context, 'input', 7)
    elif alg.parameterAsBool(parameters, '-n', context):
        return verifyRasterNum(alg, parameters, context, 'input', 2)
    elif (alg.parameterAsBool(parameters, '-l', context)
          or alg.parameterAsBool(parameters, '-a', context)):
        return verifyRasterNum(alg, parameters, context, 'input', 6)
    return True, None

==> qgis_3.10.14+dfsg.orig.tar.xz: qgis-3.10.14/python/plugins/processing/algs/grass7/ext/i_albedo.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    i_albedo.py
    -----------
    Date                 : February 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

from .i import verifyRasterNum


def checkParameterValuesBeforeExecuting(alg, parameters, context):
    if alg.parameterAsBoolean(parameters, '-m', context):
        return verifyRasterNum(alg, parameters, context, 'input', 7)
    elif alg.parameterAsBoolean(parameters, '-n', context):
        return verifyRasterNum(alg, parameters, context, 'input', 2)
    elif (alg.parameterAsBoolean(parameters, '-l', context)
          or alg.parameterAsBoolean(parameters, '-a', context)):
        return verifyRasterNum(alg, parameters, context, 'input', 6)
    return True, None
